@@ -113,6 +113,12 @@ most purposes.
 
 =back
 
+=head1 SUPPORT FOR THE PERL MULTICORE SPECIFICATION
+
+This module supports the perl multicore specification
+(L<http://perlmulticore.schmorp.de/>) for all compression (> 2000 octets) and
+decompression (> 4000 octets) functions.
+
 =head1 SEE ALSO
 
 Other Compress::* modules, especially Compress::LZV1 (an older, less
@@ -135,7 +141,7 @@ package Compress::LZF;
 require Exporter;
 require DynaLoader;
 
-$VERSION = '3.7';
+$VERSION = 3.8;
 @ISA = qw/Exporter DynaLoader/;
 %EXPORT_TAGS = (
       freeze   => [qw(sfreeze sfreeze_best sfreeze_cr sfreeze_cr_best sfreeze_c sfreeze_c_best sthaw)],
